pub struct ColoredMana {
pub color: Color,
}Expand description
A mana symbol with a number on it, representing a fixed amount of any kind of mana.
Fields
color: ColorTrait Implementations
Sourceimpl Clone for ColoredMana
impl Clone for ColoredMana
Sourcefn clone(&self) -> ColoredMana
fn clone(&self) -> ColoredMana
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ColoredMana
impl Debug for ColoredMana
Sourceimpl<'de> Deserialize<'de> for ColoredMana
impl<'de> Deserialize<'de> for ColoredMana
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ColoredMana
impl Display for ColoredMana
Sourceimpl Hash for ColoredMana
impl Hash for ColoredMana
Sourceimpl Idris for ColoredMana
impl Idris for ColoredMana
Sourceimpl Ord for ColoredMana
impl Ord for ColoredMana
Sourcefn cmp(&self, other: &ColoredMana) -> Ordering
fn cmp(&self, other: &ColoredMana) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ColoredMana
impl PartialEq for ColoredMana
Sourceimpl PartialOrd for ColoredMana
impl PartialOrd for ColoredMana
Sourceimpl Serialize for ColoredMana
impl Serialize for ColoredMana
impl Copy for ColoredMana
impl Eq for ColoredMana
impl StructuralPartialEq for ColoredMana