pub struct PhyrexianMana {
pub color: Color,
}Expand description
A mana symbol with a number on it, representing a fixed amount of any kind of mana.
Fields
color: ColorTrait Implementations
Sourceimpl Clone for PhyrexianMana
impl Clone for PhyrexianMana
Sourcefn clone(&self) -> PhyrexianMana
fn clone(&self) -> PhyrexianMana
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PhyrexianMana
impl Debug for PhyrexianMana
Sourceimpl<'de> Deserialize<'de> for PhyrexianMana
impl<'de> Deserialize<'de> for PhyrexianMana
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for PhyrexianMana
impl Display for PhyrexianMana
Sourceimpl Hash for PhyrexianMana
impl Hash for PhyrexianMana
Sourceimpl Idris for PhyrexianMana
impl Idris for PhyrexianMana
Sourceimpl Ord for PhyrexianMana
impl Ord for PhyrexianMana
Sourcefn cmp(&self, other: &PhyrexianMana) -> Ordering
fn cmp(&self, other: &PhyrexianMana) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for PhyrexianMana
impl PartialEq for PhyrexianMana
Sourceimpl PartialOrd for PhyrexianMana
impl PartialOrd for PhyrexianMana
Sourceimpl Serialize for PhyrexianMana
impl Serialize for PhyrexianMana
impl Copy for PhyrexianMana
impl Eq for PhyrexianMana
impl StructuralPartialEq for PhyrexianMana